@@ -8,7 +8,10 @@
 ##' @param dt.subset Specifies whether pars contains only a lower or
 ##'     upper triangle of an assumed symmetric matrix (most often the
 ##'     case for variance-covariance matrices), or it contains the
-##'     full matrix.
+##'     full matrix. `dt.subset="unique"` (default) means that `pars` only
+##'     contains either upper or lower diagonal matrix (including
+##'     diagonal), `dt.subset="all"` means `pars` contains both upper
+##'     and lower triangles. See details.
 ##' @param max.i By default, the maximum row number is derived as he
 ##'     maximum value in the `i` column. If more (empty ones) are
 ##'     needed, specify the maximum row number with `max.i`. This can
@@ -21,9 +24,9 @@
 ##'     output from `NMreadExt()`.
 ##' @details If pars does not contain all `i` values, they will be
 ##'     imputed with zeros. The desired matrix dimension is inferred
-##'     from `min(i)` and `max(i)`.  In case `dt.subset=="unique"`
+##'     from `min(i)` and `max(i)`. In case `dt.subset=="unique"`
 ##'     missing `j` elements will also give imputations of missing
-##'     elements.
+##'     elements. 
 ##' @import data.table
 ##' @return a matrix
 ##' @export
@@ -62,8 +65,12 @@ dt2mat <- function(pars,dt.subset="unique",max.i,fill=0,col.value) {
     i.missing <- setdiff(min(pars$i):max.i,pars$i)
     pars.mat <- rbind(pars.mat,data.table(i=i.missing,j=i.missing),fill=TRUE)
 
+    
+    
     ## note, dcast returns a keyed data.table (keys are LHS vars) so it is always ordered by i.
-    matrix.pars <- as.matrix(dcast(pars.mat,i~j,value.var="value")[,!("i")])
+    pars.matshape <- dcast(pars.mat,i~j,value.var="value")[,!("i")]
+    matrix.pars <- matrix(unlist(pars.matshape),ncol=nrow(pars.matshape))
+    
     if(!isFALSE(fill)){
         matrix.pars[is.na(matrix.pars)] <- fill
     }
