@@ -21,11 +21,17 @@
 fnExtension <- function(fn,ext){
 
     if(missing(ext) || is.null(ext)){
-        return(sub(".*\\.([^.]*)","\\1",x=fn))
+        ## disregarding any parent dirs        
+        fn <- sub(".*/","",fn)
+        ## if no dot in file name, there is no extension
+        fn[!grepl("\\.",fn)] <- ""
+        return(
+            sub(".*\\.([^/.]*)","\\1",x=fn)
+        )
     }
 
-    ext <- sub("^ *\\.{0,1}(.+)","\\.\\1",ext)
-    fn.new <- sub("\\.[^\\.]+$","",fn)
+    ext <- sub("^ *\\.{0,1}([^/]+)","\\.\\1",ext)
+    fn.new <- sub("\\.[^/\\.]+$","",fn)
     fn.new <- paste0(fn.new,ext)
     fn.new
 }
